Struct DateTimeLikeColumn
pub struct DateTimeLikeColumn<E: EntityTrait>(pub E::Column);Expand description
Supports both chrono and time DateTime
Tuple Fields
0: E::ColumnImplementations
impl<E: EntityTrait> DateTimeLikeColumn<E>
impl<E: EntityTrait> DateTimeLikeColumn<E>
pub fn enum_type_name(&self) -> Option<&'static str>
pub fn enum_type_name(&self) -> Option<&'static str>
Get the enum type name if this is a enum column
pub fn entity_name(&self) -> DynIden
pub fn entity_name(&self) -> DynIden
Get the name of the entity the column belongs to
pub fn as_column_ref(&self) -> (DynIden, DynIden)
pub fn as_column_ref(&self) -> (DynIden, DynIden)
Get the table.column reference
pub fn eq<V>(&self, v: V) -> Expr
pub fn ne<V>(&self, v: V) -> Expr
pub fn gt<V>(&self, v: V) -> Expr
pub fn gte<V>(&self, v: V) -> Expr
pub fn lt<V>(&self, v: V) -> Expr
pub fn lte<V>(&self, v: V) -> Expr
pub fn between<V>(&self, v1: V, v2: V) -> Expr
pub fn not_between<V>(&self, v1: V, v2: V) -> Expr
pub fn max(&self) -> Expr
pub fn min(&self) -> Expr
pub fn sum(&self) -> Expr
pub fn count(&self) -> Expr
pub fn is_null(&self) -> Expr
pub fn is_not_null(&self) -> Expr
pub fn if_null<V>(&self, v: V) -> Expr
pub fn is_in<V, I>(&self, v: I) -> Expr
pub fn is_not_in<V, I>(&self, v: I) -> Expr
pub fn in_subquery(&self, s: SelectStatement) -> Expr
pub fn not_in_subquery(&self, s: SelectStatement) -> Expr